import { Utilities } from '@/util/Utilities';
import { LoadingService } from '@zeedhi/common';
import { Http, IDictionary, Metadata } from '@zeedhi/core';
import { TekCardTitle } from '@zeedhi/teknisa-components-vuetify';
import { ZdCard, ZdText } from '@zeedhi/vuetify';
import { ECharts } from '@zeedhi/zd-echarts';

export class CrmDashboardController {
  public visibilidade: boolean = true;

  public currentRow: any = {};

  get visibilidadeDoFrame() {
    return !this.visibilidade;
  }

  public async dataBaseChartPie({ component }: { component: ECharts }) {
    await Http.get('/dataBaseChartPie').then((response: IDictionary) => {
      const newOptions = { ...component.options };
      if (response.data.data.length) {
        response.data.data.forEach((dados: IDictionary) => {
          const dado = {
            value: dados.QUANTIDADE,
            name: dados.FASE,
          };
          const legend = dados.FASE;
          newOptions.series[0].data.push(dado);
          newOptions.legend.data.push(legend);
        });
        component.setOption(newOptions);
      } else {
        const dado = {
          name: 'Não há dados',
          value: 100,
        };
        const legend = 'Não há dados';
        newOptions.series[0].data.push(dado);
        newOptions.legend.data.push(legend);
        component.setOption(newOptions);
      }
    });
  }

  public async dataBaseChartBarLead({ component }: { component: ECharts }) {
    Http.get('/dataBaseChartBarLead').then((response: IDictionary) => {
      const newOptions = { ...component.options };
      if (response.data.data.length) {
        response.data.data.forEach((dados: IDictionary) => {
          const mes = dados.MES;
          const leadCadastrados = dados.LEADSCADASTRADOS;
          const leadConvertidos = dados.LEADSCONVERTIDOS;
          newOptions.xAxis.data.push(mes);
          newOptions.series[0].data.push(leadCadastrados);
          newOptions.series[1].data.push(leadConvertidos);
        });
        component.setOption(newOptions);
      } else {
        newOptions.xAxis.data.push('Não há dados');
        newOptions.series[0].data.push(100);
        component.setOption(newOptions);
      }
    });
  }

  public async dataBaseChartThermometer({ component }: { component: ECharts }) {
    await Http.get('/dataBaseChartThermometer').then((response: IDictionary) => {
      const newOptions = { ...component.options };
      if (response.data.data.length) {
        response.data.data.forEach((dados: IDictionary) => {
          const dado = {
            value: dados.QUANTIDADE,
            name: dados.TERMOMETRO,
          };
          const colorThermometer = dados.CORTERMOMETRO;
          newOptions.series[0].color.push(colorThermometer);
          newOptions.series[0].data.push(dado);
        });
        component.setOption(newOptions);
      } else {
        const dado = {
          name: 'Não há dados',
          value: 100,
        };
        const legend = 'Não há dados';
        newOptions.series[0].data.push(dado);
        newOptions.legend.data.push(legend);
        component.setOption(newOptions);
      }
    });
  }

  public dataBaseCardTask() {
    LoadingService.show();
    Http.get('/dataBaseCardTask', {
    }).then((response) => {
      const dataTask = response.data;
      if (response.data.data.length) {
        Metadata.getInstance<TekCardTitle>('title-rightSlot_late').title = dataTask.data[0].STATUS;
        const quantityLate = dataTask.data[0].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_late').text = quantityLate !== 0 ? quantityLate : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_future').title = dataTask.data[1].STATUS;
        const quantityFuture = dataTask.data[1].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_future').text = quantityFuture !== 0 ? quantityFuture : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_today').title = dataTask.data[2].STATUS;
        const quantityToday = dataTask.data[2].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_today').text = quantityToday !== 0 ? quantityToday : '0';
      }
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public dataBaseCardCommitment() {
    LoadingService.show();
    Http.get('/dataBaseCardCommitment', {
    }).then((response) => {
      const dataCommitment = response.data;
      if (response.data.data.length) {
        Metadata.getInstance<TekCardTitle>('title-rightSlot_late_commitment').title = dataCommitment.data[0].STATUS;
        const quantityLate = dataCommitment.data[0].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_late_commitment').text = quantityLate !== 0 ? quantityLate : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_future_commitment').title = dataCommitment.data[1].STATUS;
        const quantityFuture = dataCommitment.data[1].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_future_commitment').text = quantityFuture !== 0 ? quantityFuture : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_today_commitment').title = dataCommitment.data[2].STATUS;
        const quantityToday = dataCommitment.data[2].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_today_commitment').text = quantityToday !== 0 ? quantityToday : '0';
      }
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public dataBaseCardOpportunity() {
    LoadingService.show();
    Http.get('/dataBaseCardOpportunity', {
    }).then((response) => {
      const dataOpportunity = response.data;
      if (response.data.data.length) {
        Metadata.getInstance<TekCardTitle>('title-rightSlot_late_opportunity').title = dataOpportunity.data[0].STATUS;
        const quantityLate = dataOpportunity.data[0].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_late_opportunity').text = quantityLate !== 0 ? quantityLate : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_future_opportunity').title = dataOpportunity.data[1].STATUS;
        const quantityFuture = dataOpportunity.data[1].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_future_opportunity').text = quantityFuture !== 0 ? quantityFuture : '0';
        Metadata.getInstance<TekCardTitle>('title-rightSlot_today_opportunity').title = dataOpportunity.data[2].STATUS;
        const quantityToday = dataOpportunity.data[2].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_today_opportunity').text = quantityToday !== 0 ? quantityToday : '0';
      }
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public dataBaseCardOccurrences() {
    LoadingService.show();
    Http.get('/dataBaseCardOccurrences', {
    }).then((response) => {
      const dataOccurrences = response.data;
      const numberOfOccurrence = dataOccurrences.data[0].QUANTIDADE;
      if (numberOfOccurrence > 0) {
        Metadata.getInstance<ZdCard>('card_occurrences').color = 'error';
        console.warn(Metadata.getInstance<ZdCard>('card_occurrences'));
        Metadata.getInstance<TekCardTitle>('title-rightSlot_late_occurrences').title = dataOccurrences.data[0].STATUS;
        const quantityLate = dataOccurrences.data[0].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_late_occurrences').text = quantityLate !== 0 ? quantityLate : '0';
      } else {
        Metadata.getInstance<TekCardTitle>('title-rightSlot_late_occurrences').title = dataOccurrences.data[0].STATUS;
        const quantityLate = dataOccurrences.data[0].QUANTIDADE;
        Metadata.getInstance<ZdText>('resizeResult_late_occurrences').text = quantityLate !== 0 ? quantityLate : '0';
      }
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }
}
